package Stanford::WebApp::Logdump::Util;

use strict;
use warnings;
use autodie;

use Carp;
use Net::Remctl;

use Stanford::Orange::Util qw(kerberos_ticket_cache_no_afs);

require Exporter;
use base qw(Exporter);

our @EXPORT_OK = qw(
  refresh_krb5_cache
  run_remctl
);

sub refresh_krb5_cache {
    my ($keytab_file, $cache_file) = @_ ;

    if (!$keytab_file) {
        croak 'no keytab_file parameter passed' ;
    }

    if (!$cache_file) {
        croak 'no cache_file parameter passed' ;
    }

    return kerberos_ticket_cache_no_afs($keytab_file, $cache_file);
}

# Returns the tuple:
#
# (stdout, stderr, exit_code)
sub run_remctl {
    my ($hostname, $port, $principal, $command, @other_args) = @_ ;

    my $result = remctl($hostname, $port, $principal, $command, @other_args);

    if ($result->error) {
        my $args_fmted = join(', ', @other_args) ;
        my $remctl_cmd = "remctl($hostname, $port, $principal, $command, $args_fmted)";
        croak "remctl command '$remctl_cmd' failed with error " . $result->error ;
    } else {
        return ($result->stdout, $result->stderr, $result->status) ;
    }
}

1;
